/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.liveconsole;

import java.io.File;
import java.io.IOException;
import java.util.Date;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.ow2.petals.tools.webadmin.cron.CollectorManager;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;
import org.ow2.petals.tools.webadmin.datacollector.server.CollectorServer;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorClientDoesNotExistException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerNotInitializedException;
import org.ow2.petals.tools.webadmin.ui.administration.InstallComponent;
import org.ow2.petals.tools.webadmin.ui.administration.UninstallComponent;
import org.ow2.petals.tools.webadmin.ui.infra.action.AuthentifiedAction;
import org.ow2.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.util.StringHelper;

import com.oreilly.servlet.MultipartRequest;

/**
 * Display all BC and SE for a server request params : server
 * 
 * @author mcarpentier - EBM Websourcing
 * 
 */
public class UploadAndInstallFile extends AuthentifiedAction {

    final Logger log = Logger.getLogger(UploadAndInstallFile.class);

    private static final String actionTitle = "install entity";

    @Override
    public ActionForward executeAuthentified(ActionMapping iActionMapping, ActionForm iActionForm,
            HttpServletRequest iServletRequest, HttpServletResponse iServletResponse) {
        InfoBean infoBean = new InfoBean();
        AdminSession adminSession = AdminSession.getAdminSession(iServletRequest.getSession());
        String serverName = iServletRequest.getParameter("server");
        String fileName = iServletRequest.getParameter("fileName");
        String fileType = iServletRequest.getParameter("fileType");

        /** wrong request settings * */
        if (StringHelper.isNullOrEmpty(serverName)) {
            this.fillInfoBean(adminSession, "Error: you must select a destination server",
                    InfoBean.ERROR_MESSAGE);
            return iActionMapping.findForward("success");
        }
        if ((StringHelper.isNullOrEmpty(fileName)) || (!(fileName.endsWith(".zip")))) {
            this
                    .fillInfoBean(adminSession, "Error: archive must be a .zip",
                            InfoBean.ERROR_MESSAGE);
            return iActionMapping.findForward("success");
        }
        if ((StringHelper.isNullOrEmpty(fileType))
                || ((!AdminSession.LASZLO_COMPONENT.equalsIgnoreCase(fileType)) && (!AdminSession.LASZLO_SA
                        .equalsIgnoreCase(fileType)))) {
            this
                    .fillInfoBean(adminSession,
                            "Error: could'nt determine file type (sa or component)",
                            InfoBean.ERROR_MESSAGE);
            return iActionMapping.findForward("success");
        }

        /** set upload dir * */
        ServletContext context = iServletRequest.getSession().getServletContext();
        String reqPath = iServletRequest.getContextPath();
        reqPath = reqPath.substring(reqPath.lastIndexOf("/") + 1);
        String realContextPath = context.getRealPath(iServletRequest.getContextPath());
        String rootPath = realContextPath.substring(0, realContextPath.lastIndexOf(reqPath));
        File uploadDir = new File(rootPath + "upload/");
        if (!(uploadDir.exists())) {

            if (!(uploadDir.mkdir())) {
                this.fillInfoBean(adminSession, "Error: can't create upload directory",
                        InfoBean.ERROR_MESSAGE);
                return iActionMapping.findForward("success");
            }

        }

        String tmpDir = String.valueOf(new Date().getTime());
        uploadDir = new File(rootPath + "upload/" + tmpDir);
        if (!(uploadDir.exists())) {
            if (!(uploadDir.mkdir())) {
                this.fillInfoBean(adminSession, "Error: can't create upload directory",
                        InfoBean.ERROR_MESSAGE);
                return iActionMapping.findForward("success");
            }
        }

        String saveDirectory = uploadDir.getAbsolutePath() + File.separator;
        // size limitation is 100Mb
        int maxPostSize = 100 * 1024 * 1024;

        try {
            MultipartRequest multi = new MultipartRequest(iServletRequest, saveDirectory,
                    maxPostSize, "MS950");

            if (serverName != null) {
                CollectorServer collector = CollectorManager.getCollector();

                // constructs http url of file uploaded
                String jspUrl = iServletRequest.getRequestURL().toString();
                int lastSeparator = jspUrl.lastIndexOf("/") + 1;
                String httpUrl = jspUrl.substring(0, lastSeparator) + "upload/" + tmpDir + "/"
                        + fileName;
                if (AdminSession.LASZLO_COMPONENT.equalsIgnoreCase(fileType)) {
                    collector.getCollectorClient(serverName).getInstallService().installComponent(
                            httpUrl);
                } else if (AdminSession.LASZLO_SA.equalsIgnoreCase(fileType)) {
                    collector.getCollectorClient(serverName).getDeployService()
                            .deployServiceAssembly(httpUrl);
                }
            }
        } catch (DataCollectorClientException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, actionTitle, e.getMessage());
            this.log.error("Error : can't " + actionTitle, e);
            return iActionMapping.findForward("success");
        } catch (DataCollectorServerException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, actionTitle, e.getMessage());
            this.log.error("Error : can't " + actionTitle, e);
            return iActionMapping.findForward("success");
        } catch (IOException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, actionTitle, e.getMessage());
            this.log.error("Error : can't " + actionTitle, e);
            return iActionMapping.findForward("success");
        } catch (DataCollectorClientDoesNotExistException e) {
            this.fillInfoBean(adminSession,
                    "Can't reach PEtALS client, your server list must be out of date",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Error : can't " + actionTitle, e);
        } catch (DataCollectorServerNotInitializedException e) {
            CollectorManager.resetCollector();
            this.fillInfoBean(adminSession, "Connection to PEtALS lost, please refresh",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Connection to PEtALS lost : can't " + actionTitle, e);
        }

        /** deals with info messages * */
        this.fillInfoBean(adminSession, "Component successfully installed",
                InfoBean.SUCCESS_MESSAGE);
        return iActionMapping.findForward("success");

    }
}
