/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.monitoring;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.DynaActionForm;
import org.ow2.petals.tools.webadmin.cron.CollectorManager;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorClientDoesNotExistException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerNotInitializedException;
import org.ow2.petals.tools.webadmin.ui.infra.action.MonitoringAction;
import org.ow2.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.ow2.petals.tools.webadmin.ui.infra.bean.MessageExchangeLVO;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.ui.infra.util.MessageExchangeLVOComparator;
import org.ow2.petals.tools.webadmin.ui.logon.LogonUtil;
import org.ow2.petals.tools.webadmin.util.DataCollectorHelper;
import org.ow2.petals.tools.webadmin.util.StringHelper;

/**
 * @author mcarpentier - EBM Websourcing
 */
public class ShowExchanges extends MonitoringAction {

    private static final String actionTitle = "get PEtALS messages exchanges";

    public static String MESSAGES_PER_PAGE = "10";

    final Logger log = Logger.getLogger(ShowExchanges.class);

    @Override
    public ActionForward executeMonitoringAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) {

        final AdminSession adminSession = AdminSession
                .getAdminSession(iServletRequest.getSession());

        /** set navigation info* */
        adminSession.setSelectedMenu(AdminSession.MONITORING);

        /** request parameters * */
        final DynaActionForm form = (DynaActionForm) iActionForm;
        String startMessage = iServletRequest.getParameter("startMessage");
        String messagesPerPage = iServletRequest.getParameter("messagesPerPage");
        if (StringHelper.isNullOrEmpty(startMessage)) {
            startMessage = "0";
        }
        if (StringHelper.isNullOrEmpty(messagesPerPage)) {
            messagesPerPage = ShowExchanges.MESSAGES_PER_PAGE;
        }

        try {

            List<MessageExchangeLVO> exchanges = DataCollectorHelper.getExchanges();

            if (exchanges != null) {
                Collections.sort(exchanges, new MessageExchangeLVOComparator());

                /** apply filter on sorted list* */
                final List<MessageExchangeLVO> result = new ArrayList<MessageExchangeLVO>();

                final int currentMsg = Integer.parseInt(startMessage);
                final int finalMsg = Integer.parseInt(messagesPerPage) + currentMsg - 1;

                for (int i = currentMsg; (i <= finalMsg && (i < exchanges.size())); i++) {
                    result.add(exchanges.get(i));
                }

                form.set("startMessage", startMessage);
                form.set("messagesPerPage", messagesPerPage);
                form.set("totalMessages", String.valueOf(exchanges.size()));

                form.set("exchanges", result);

            }
        } catch (final DataCollectorClientException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, ShowExchanges.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + ShowExchanges.actionTitle, e);
        } catch (final DataCollectorServerException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, ShowExchanges.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + ShowExchanges.actionTitle, e);
        } catch (DataCollectorServerNotInitializedException e) {
            CollectorManager.resetCollector();
            this.fillInfoBean(adminSession, "Connection to PEtALS lost, please refresh",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Connection to PEtALS lost : can't " + actionTitle, e);
            return LogonUtil.getLogonForward(iServletRequest);
        }

        return iActionMapping.findForward("success");
    }
}
