/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005-2006 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.util;

/**
 * @author mcarpentier
 * 
 */
public class Formatter {
    final static long SECOND = 1000;

    final static long MINUTE = 60 * Formatter.SECOND;

    final static long HOUR = 60 * Formatter.MINUTE;

    final static long DAY = 24 * Formatter.HOUR;

    public static String formatNanoTime(long t) {
        final long ms = t / 1000000;
        return Formatter.formatTime(ms);
    }

    public static String formatSize(String size) {
        String result = "";
        int i = size.length();
        for (i = size.length(); i - 3 > 0; i = i - 3) {
            if (StringHelper.isNotNullAndNotEmpty(result)) {
                result = size.substring(i - 3, i) + " " + result;
            } else {
                result = size.substring(i - 3, i);
            }
        }
        if (StringHelper.isNotNullAndNotEmpty(result)) {
            result = size.substring(0, i) + " " + result;
        } else {
            result = size.substring(0, i);
        }
        return result;
    }

    /**
     * Give the duration
     * 
     * @param t
     *            the duration in ms to format
     * @return a formatted string
     */
    public static String formatTime(long t) {
        String str;
        if (t < 1 * Formatter.MINUTE) {
            final String seconds = String.format("%.3f", t / (double) Formatter.SECOND);
            str = seconds + " secs";
        } else {
            long remaining = t;
            final long days = remaining / Formatter.DAY;
            remaining %= 1 * Formatter.DAY;
            final long hours = remaining / Formatter.HOUR;
            remaining %= 1 * Formatter.HOUR;
            final long minutes = remaining / Formatter.MINUTE;

            if (t >= 1 * Formatter.DAY) {
                str = days + " days " + hours + " hours " + minutes + " minutes ";
            } else if (t >= 1 * Formatter.HOUR) {
                str = hours + " hours " + minutes + " minutes ";
            } else {
                str = minutes + " minutes ";
            }
        }
        return str;
    }
}
